# Echo

## Description

This skill sends back the contents of any message it receives.

## Behaviours 

* echo: outputs messages

## Handlers

* echo: handles default messages for echoing back the contents of any message received

## Links

* <a href="https://docs.fetch.ai/aea/quickstart/" target="_blank">Quick Start</a>
* <a href="https://docs.fetch.ai/aea/build-aea-programmatically/" target="_blank">Programmatically Build an AEA</a>